/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.collections.adapters;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.NoSuchElementException;

/**
 * "Concatenated" iterator over several iterators. You can chain several iterators into one!
 * @author borisman
 *
 * @param <E>
 */
public class ChainIterator<E> implements Iterator<E> {
	
	private final List<Iterator<E>> iterators = new ArrayList<Iterator<E>>();
	private int currentIdx = 0;
	private Iterator<E> current;
	private Boolean hasNext = null;
	private boolean nextHasBeenCalled = false;
	
	public void addIterator (final Iterator<E> it) {
		iterators.add(it);
	}
	
	@Override public boolean hasNext() {
		if (hasNext == null) {
			while (currentIdx < iterators.size()) {
				current = iterators.get(currentIdx);
				hasNext = current.hasNext();
				if (hasNext) return true;
				currentIdx ++;
			}
			hasNext = false;
		}
		return hasNext;
	}

	@Override public E next() {
		if (!hasNext()) throw new NoSuchElementException();
		final E res = current.next();
		hasNext = null;
		nextHasBeenCalled = true;
		return res;
	}

	@Override public void remove() {
		if (!nextHasBeenCalled) throw new IllegalStateException();
		current.remove();
	}

}
