/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.collections.adapters;

import java.util.Iterator;
import java.util.NoSuchElementException;

import junit.framework.Assert;

import org.builtu.collections.adapters.ArrayIterator;
import org.junit.Test;

public class TestArrayIterator {
	protected Integer [] array;
	
	protected Iterator<Integer> make () {
		return new ArrayIterator<Integer>(array);
	}
	
	@Test public void testEmpty () {
		array = new Integer[0];
		Assert.assertFalse(make().hasNext());
	}
	
	@Test(expected=NoSuchElementException.class) public void testEmptyNext() {
		array = new Integer[0];
		make().next();
	}

	@Test(expected=UnsupportedOperationException.class) public void testRemove() {
		array = new Integer[]{1,2};
		final Iterator<Integer> it = make();
		it.remove();
	}
	
	@Test public void testOne() {
		array = new Integer[]{1};
		checkOne(make());
	}
	
	protected static void checkOne(final Iterator<Integer> it) {
		Assert.assertTrue(it.hasNext());
		Assert.assertEquals(1, (int)it.next());
		Assert.assertFalse(it.hasNext());
	}
	
	@Test(expected=NoSuchElementException.class) public void testOneNext() {
		array = new Integer[]{1};
		final Iterator<Integer> it = make();
		it.next();
		it.next();
	}

	@Test public void testTwo () {
		array = new Integer[]{1,2};
		checkTwo(make());
	}

	private static void checkTwo(final Iterator<Integer> it) {
		Assert.assertTrue(it.hasNext());
		Assert.assertEquals(1, (int)it.next());
		Assert.assertTrue(it.hasNext());
		Assert.assertEquals(2, (int)it.next());
		Assert.assertFalse(it.hasNext());
	}
	
	@Test public void testThree () {
		array = new Integer[]{1,2,3};
		checkThree(make());
	}

	private void checkThree(final Iterator<Integer> it) {
		Assert.assertTrue(it.hasNext());
		Assert.assertEquals(1, (int)it.next());
		Assert.assertTrue(it.hasNext());
		Assert.assertEquals(2, (int)it.next());
		Assert.assertTrue(it.hasNext());
		Assert.assertEquals(3, (int)it.next());
		Assert.assertFalse(it.hasNext());
	}
	
}
