/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.config.module.refresh;

import java.util.Date;

import org.builtu.util.commutil.DateUtil;


/**
 * Refresh every day at specified hour (or later) 
 * @author borisman
 */
public class DailyRefreshStrategy extends AbstractRefreshStrategyBase implements RefreshStrategy {

	private Date lastRefreshedDay = new Date(0);
	
	private int atHour = 0;
	
	public int getAtHour() {
		return atHour;
	}

	public void setAtHour(final int atHour) {
		this.atHour = atHour;
	}

	@Override public boolean hasToBeRefreshed() {
		final long addDay = DateUtil.addDay(1);
		final long addHour = DateUtil.addHour(atHour);
		final long hasToBeRefreshedAfter = lastRefreshedDay.getTime()+addDay+addHour;
		final long now = clock.currentTimeMillis();
		return now >= hasToBeRefreshedAfter;
	}

	@Override public void refreshed() {
		lastRefreshedDay = now();
	}
	
	private Date now() {
		return DateUtil.truncateToDay(new Date(clock.currentTimeMillis()));
	}
	
}
