/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.persistence.hibernate;

import org.builtu.collections.Scrollable;
import org.hibernate.ScrollableResults;


public class ScrollableAdapter<ENTITY> implements Scrollable<ENTITY> {
	
	final ScrollableResults backend;

	public ScrollableAdapter(final ScrollableResults backend) {
		this.backend = backend;
	}

	@Override public void afterLast() {
		backend.afterLast();
	}

	@Override public void beforeFirst() {
		backend.beforeFirst();
	}

	@Override public void close() {
		backend.close();
	}

	@Override public boolean first() {
		return backend.first();
	}

	@SuppressWarnings("unchecked")
	@Override public ENTITY get() {
		return (ENTITY) backend.get(0);
	}

	@Override public int getRowNumber() {
		return backend.getRowNumber();
	}

	@Override public boolean isFirst() {
		return backend.isFirst();
	}

	@Override public boolean isLast() {
		return backend.isLast();
	}

	@Override public boolean last() {
		return backend.last();
	}

	@Override public boolean next() {
		return backend.next();
	}

	@Override public boolean previous() {
		return backend.previous();
	}

	@Override public boolean scroll(final int i) {
		return backend.scroll(i);
	}

	@Override public boolean setRowNumber(final int rowNumber) {
		return backend.setRowNumber(rowNumber);
	}

}
