/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.util.clown;

import java.io.Serializable;

import junit.framework.Assert;

import org.builtu.testing.BasicTestCase;
import org.builtu.util.clown.Clown;
import org.junit.Test;


public abstract class AbstractTestClown extends BasicTestCase {
	
	protected abstract Clown makeClown();
	
	private<E extends Serializable> void doTest(final E o, final boolean couldBeSame) {
		final Object copy = makeClown().deepClone(o);
		check(o, copy, couldBeSame);
	}
	
	private void check(final Object original, final Object copy, final boolean couldBeSame) {
		if (!couldBeSame) Assert.assertFalse("original == copy", original == copy);
		Assert.assertTrue("original not equals copy", original.equals(copy));
	}

	@Test public void testString() {
		doTest("1", true); 
	}
	
	@Test public void testArray() {
		final int [] original = new int [] {1,2,3};
		final int [] copy = makeClown().deepClone(original);
		Assert.assertFalse("original == copy", original == copy);
		super.assertArraysEquals(original, copy);
	}

	@Test public void testInteger() {
		doTest(new Integer(1), true); 
	}
	
	@Test public void testClass() {
		final Class<AbstractTestClown> original = AbstractTestClown.class;
		final Class<AbstractTestClown> copy = makeClown().deepClone(original);
		
		Assert.assertSame(original, copy);
	}
	
	@Test public void testSerializable() {
		doTest(new ComplexClassSerializable(super.random), false);
	}

	@Test public void testExternalizable() {
		doTest(new ComplexClassExternalizable(super.random), false);
	}
	

}
