/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.util.commutil;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import org.builtu.exceptions.FatalError;
import org.builtu.exceptions.ResourceNotFound;


public class ClasspathUtil {

	public static InputStream getClassResource(final Class<?> klass, final String ext) {
	    final String path = classResourcePath(klass, ext);
	    final InputStream in = klass.getResourceAsStream(path);
	    if (in == null) throw new ResourceNotFound(path);
	    return in;
	}
	
	public static String readUTF8ClassResource(final String url) throws IOException {
		final InputStream in = IOUtil.class.getResourceAsStream(url);
		try {
			final StringBuilder res = new StringBuilder(4096);
			final byte [] buffer = new byte[4096];
			int read = in.read(buffer);
			while (read>=0) {
				res.append(new String(buffer, 0, read, StringUtil.utf8Charset));
				read = in.read(buffer);
			}
			return res.toString();
		} finally {
			in.close();
		}
	}	

	public static String readUTF8ClassResource(final Class<?> klass, final String ext) {
		final InputStream in = getClassResource(klass, ext);
		try {
			try {
				return IOUtil.readUTF8Contents(in);
			} catch (final IOException e) {
				throw new FatalError(e);
			}
		} finally {
			try {
				in.close();
			} catch (final IOException e) {
				throw new FatalError(e);
			}
		}
	}
	
    private static String classResourcePath(final Class<?> klass, final String ext) {
        return "/" + klass.getName().replace('.', '/') + ext;
    }

	public static Properties propertiesForClass(final Class<?> klass) {
		final Properties res = new Properties();
		final InputStream in = getClassResource(klass, ".properties");
		try {
			try {
				res.load(in);
			} finally {
				in.close();
			}
		} catch (final IOException e) {
			throw new FatalError(e);
		}
		return res;
	}
	
	
}
