/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.util.commutil;

import java.util.ArrayList;
import java.util.List;

import junit.framework.Assert;

import org.builtu.util.commutil.Util;
import org.junit.Test;


public class TestUtilSplitList {
    @Test public void testEmpty1 () {
        final List<Integer> source = new ArrayList<Integer>();
        final List<List<Integer>> l = Util.splitList(source, 1);
        Assert.assertEquals(1, l.size());
        Assert.assertEquals(0, l.get(0).size());
    }
    @Test public void testEmpty2 () {
        final List<Integer> source = new ArrayList<Integer>();
        final List<List<Integer>> l = Util.splitList(source, 2);
        Assert.assertEquals(2, l.size());
        Assert.assertEquals(0, l.get(0).size());
        Assert.assertEquals(0, l.get(1).size());
    }
    @Test public void testEmpty3 () {
        final List<Integer> source = new ArrayList<Integer>();
        final List<List<Integer>> l = Util.splitList(source, 3);
        Assert.assertEquals(3, l.size());
        Assert.assertEquals(0, l.get(0).size());
        Assert.assertEquals(0, l.get(1).size());
        Assert.assertEquals(0, l.get(2).size());
    }
    @Test public void testOne1 () {
        final List<Integer> source = new ArrayList<Integer>();
        source.add(100);
        final List<List<Integer>> l = Util.splitList(source, 1);
        Assert.assertEquals(1, l.size());
        Assert.assertEquals(1, l.get(0).size());
        Assert.assertEquals(100, (int)l.get(0).get(0));
    }
    @Test public void testOne2 () {
        final List<Integer> source = new ArrayList<Integer>();
        source.add(100);
        final List<List<Integer>> l = Util.splitList(source, 2);
        Assert.assertEquals(2, l.size());
        Assert.assertEquals(1, l.get(0).size());
        Assert.assertEquals(100, (int)l.get(0).get(0));
        Assert.assertEquals(0, l.get(1).size());
    }
    @Test public void testOne3 () {
        final List<Integer> source = new ArrayList<Integer>();
        source.add(100);
        final List<List<Integer>> l = Util.splitList(source, 3);
        Assert.assertEquals(3, l.size());
        Assert.assertEquals(1, l.get(0).size());
        Assert.assertEquals(100, (int)l.get(0).get(0));
        Assert.assertEquals(0, l.get(1).size());
        Assert.assertEquals(0, l.get(2).size());
    }
    @Test public void testTwo1 () {
        final List<Integer> source = new ArrayList<Integer>();
        source.add(100);
        source.add(101);
        final List<List<Integer>> l = Util.splitList(source, 1);
        Assert.assertEquals(1, l.size());
        Assert.assertEquals(2, l.get(0).size());
        Assert.assertEquals(100, (int)l.get(0).get(0));
        Assert.assertEquals(101, (int)l.get(0).get(1));
    }
    @Test public void testTwo2 () {
        final List<Integer> source = new ArrayList<Integer>();
        source.add(100);
        source.add(101);
        final List<List<Integer>> l = Util.splitList(source, 2);
        Assert.assertEquals(2, l.size());
        Assert.assertEquals(1, l.get(0).size());
        Assert.assertEquals(100, (int)l.get(0).get(0));
        Assert.assertEquals(1, l.get(1).size());
        Assert.assertEquals(101, (int)l.get(1).get(0));
    }
    @Test public void testTwo3 () {
        final List<Integer> source = new ArrayList<Integer>();
        source.add(100);
        source.add(101);
        final List<List<Integer>> l = Util.splitList(source, 3);
        Assert.assertEquals(3, l.size());
        Assert.assertEquals(1, l.get(0).size());
        Assert.assertEquals(100, (int)l.get(0).get(0));
        Assert.assertEquals(1, l.get(1).size());
        Assert.assertEquals(101, (int)l.get(1).get(0));
        Assert.assertEquals(0, l.get(2).size());
    }
}
