/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.util.commutil;

import junit.framework.Assert;

import org.builtu.util.commutil.Util;
import org.junit.Test;



public class TestUtilUrlEncodePath {
	
	@Test public void empty() {
		Assert.assertEquals("", Util.urlencodePath(""));
	}
	
	@Test public void simple() {
		Assert.assertEquals("avto", Util.urlencodePath("avto"));
	}
	
	@Test public void single() {
		Assert.assertEquals("%D0%B0%D0%B2%D1%82%D0%BE", Util.urlencodePath("авто"));
	}
	
	private String original, expected;
	
	private void check() {
		final String actual = Util.urlencodePath(original);
		Assert.assertEquals(expected, actual);
	}
	
	@Test public void multiple() {
		original = "авто/машина";
		expected = "%D0%B0%D0%B2%D1%82%D0%BE/%D0%BC%D0%B0%D1%88%D0%B8%D0%BD%D0%B0";
		check();
	}
	
	@Test public void dynamic() {
		original = "авто/path?dynamic_part&params";
		expected = "%D0%B0%D0%B2%D1%82%D0%BE/path?dynamic_part&params";
		check();
	}
	
	@Test public void testWhitespace() {
		original = " + ";
		expected = "%20%2B%20";
		check();
	}
}
