/**
	This file is part of BUILTU.

    BUILTU is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BUILTU is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser Public License for more details.

    You should have received a copy of the GNU Lesser Public License
    along with BUILTU.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2005-2010 Pasko Boris
 */
package org.builtu.util.html;

import junit.framework.Assert;

import org.builtu.util.html.HtmlUtil;
import org.junit.Before;
import org.junit.Test;


public class TestHtmlUtilClean {
	
	private String html;
	private String expected;
	
	private void check () {
		Assert.assertEquals(expected, HtmlUtil.clean(html));
	}
	
	@Before public void before() {
		html = expected = null;
	}
	
	@Test public void testEmpty() {
		expected = html = "";
		check();
	}
	
	@Test public void testSimpleText() {
		expected = html = "simple text";
		check();
	}
	
	@Test public void testSimpleFormattingTags() {
		expected = html = "<br><b>bold</b> <strong >strong</strong> <i>italic</i><U>unerline</U><br/><br>";
		check();
	}
	
	@Test public void testStripsScripts() {
		html = "<script> sdfsdfsfd </script>aaa";
		expected = "&lt;script&gt; sdfsdfsfd &lt;/script&gt;aaa";
		check();
	}
	
	@Test public void testCleanBad() {
		html = "<script";
		expected = "&lt;script";
		check();
	}

	@Test public void testCleanClosed() {
		html = "<hr/>hello";
		expected = "&lt;hr/&gt;hello";
		check();
	}
	
}
